var clearFieldsUrl = "{% url 'core_curate_clear_fields' %}";
var saveFormUrl = "{% url 'core_curate_save_form' %}";
var validateFormUrl = "{% url 'core_curate_validate_form' %}";
var cancelChangesUrl = "{% url 'core_curate_cancel_changes' %}";
var cancelFormUrl = "{% url 'core_curate_cancel_form' %}";
var curateIndexUrl = "{% url 'core_curate_index' %}";
