{% load i18n %}
<h1>Data Entry</h1>

Here you can fill in the {{CUSTOM_DATA}} form. Once it is completed, you can Validate the {% trans "form_label" %}.
You won't be able to reach the review page before the document is valid according to the selected template. From the review page, you will be able to curate the {% trans "record_label" %}.
The 'Save {% trans "form_label"|title %}' button allows you to save partial data that you may want to edit later. This will only save a temporary document and won't actually curate data.
All grayed elements are optional. Thus, all elements written in black are required. The document may still be valid with empty elements.
There are no validation on empty fields if no such constraint is defined in the template.
Thus, an empty string of characters may not raise a validation error, but an empty number will.

<div class="toolbar">
	<div class="float-right">
		<button class="btn btn-danger clear-fields mr-auto"><i class="fas fa-eraser"></i> Clear Fields </button>
        <button class="btn btn-danger cancel-changes mr-auto"><i class="fas fa-sync"></i> Cancel Changes </button>
        <button class="btn btn-danger cancel-form mr-auto"><i class="fas fa-trash"></i> Delete {% trans "form_label"|title %} </button>
    	<button class="btn btn-secondary save-form mr-auto"><i class="fas fa-save"></i> Save {% trans "form_label"|title %} </button>
    	<button class="btn btn-secondary download mr-auto"><i class="fas fa-download"></i> Download </button>
        <button class="btn btn-primary validate"><i class="fas fa-check"></i> Validate </button>
	</div>
    <br/><br/>

    <span>Title: {{data.data_structure.name}}</span>

    <div id="xsdForm" class="xsdForm">
        {{data.xsd_form|safe}}
    </div>
</div>

<div id="curate_data_structure_id" style="display: none;">{{ data.data_structure.id }}</div>