{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}
{% load i18n %}

{% block modal_id %}cancel-form-modal{% endblock %}
{% block modal_title %}Delete {% trans "form_label"|title %}{% endblock %}

{% block modal_body %}
Are you sure you want to delete the {% trans "form_label" %}? All your changes will be lost and the {% trans "form_label" %} will be deleted.
{% endblock %}

{% block modal_footer %}
<button class="btn btn-secondary pull-left" data-dismiss="modal"><i class="fas fa-times"></i> No</button>
<button id="btn-cancel-form" class="btn btn-danger">
    <i class="fas fa-trash"></i> Yes, delete {% trans "form_label" %}
</button>
{% endblock %}