{% extends "core_main_app/_render/admin/theme/tools/section.html" %}
{% load staticfiles %}
{% load i18n %}

{% block section_title %} {% trans "form_label"|title %} Detail {% endblock %}

{% block section_content %}
<div class="row">
    <div class="col-md-12">
        {% include 'core_curate_app/admin/detail.html' %}
    </div>
</div>
{% endblock %}