{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}
{% load i18n %}

{% block modal_id %}save-form-modal{% endblock %}
{% block modal_title %}Save {% trans "form_label"|title %}{% endblock %}

{% block modal_body %}
Are you sure you want to save the {% trans "form_label" %}?
{% endblock %}

{% block modal_footer %}
<button class="btn btn-secondary pull-left" data-dismiss="modal"><i class="fas fa-times"></i> Cancel</button>
<button id="btn-save-form" class="btn btn-primary"><i class="fas fa-save"></i> Save</button>
{% endblock %}