{% load staticfiles %}
{% load i18n %}

<div class="title-page">Select Template</div>

<p>
    Select a template from the following table. Once you make your selection, start a new document or open an existing
    {% trans "form_label" %} or start from an uploaded document.  It will automatically load the appropriate
    {% trans "form_label" %} and display it on the next page.
</p>

<div id="template_selection">
    <h3 class="text-center">Templates</h3>
    {% if data.templates_version_manager or data.userTemplates %}
        <table class="table fixed-table">
            <colgroup>
                <col class="col-width-75">
                <col class="col-width-25">
            </colgroup>
            {% include 'core_main_app/user/template/list_header.html' with object_type='Template' %}
            {% include 'core_curate_app/user/list/list.html' with object_list=data.templates_version_manager owner='Global' object_type='Template' %}
            {% include 'core_curate_app/user/list/list.html' with object_list=data.userTemplates owner=request.user object_type='Template' %}
        </table>
    {% else %}
        <p class="text-center">No template uploaded yet.</p>
    {% endif %}
</div>

{% include 'core_curate_app/user/curate_full_start.html' %}
