""" Rights for core curate app
"""

curate_content_type = "core_curate_app"
curate_access = "access_curate"
curate_view_data_save_repo = "view_data_save_repo"
curate_data_structure_access = "access_curate_data_structure"
