{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}

{% block modal_id %}cancel-changes-modal{% endblock %}
{% block modal_title %}Cancel Changes{% endblock %}

{% block modal_body %}
Are you sure you want to cancel your changes? All your changes since the last save will be lost.
{% endblock %}

{% block modal_footer %}
<button class="btn btn-secondary pull-left" data-dismiss="modal"><i class="fas fa-times"></i> No</button>
<button id="btn-cancel-changes" class="btn btn-danger">
    <i class="fas fa-sync"></i> Yes, cancel changes
</button>
{% endblock %}